@@ -7,7 +7,7 @@ RDF::Query::Plan::Clear - Executable query plan for CLEAR operations.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Clear version 2.907.
+This document describes RDF::Query::Plan::Clear version 2.908.
 
 =head1 METHODS
 
@@ -36,7 +36,7 @@ use RDF::Query::VariableBindings;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.907';
+	$VERSION	= '2.908';
 }
 
 ######################################################################
@@ -59,6 +59,7 @@ sub new {
 sub execute ($) {
 	my $self	= shift;
 	my $context	= shift;
+	$self->[0]{delegate}	= $context->delegate;
 	if ($self->state == $self->OPEN) {
 		throw RDF::Query::Error::ExecutionError -text => "CLEAR plan can't be executed while already open";
 	}
@@ -108,6 +109,9 @@ sub next {
 	
 	my $l		= Log::Log4perl->get_logger("rdf.query.plan.clear");
 	$self->close();
+	if (my $d = $self->delegate) {
+		$d->log_result( $self, $self->[0]{ok} );
+	}
 	return $self->[0]{ok};
 }
 
